/*!  ==========================================================================
  Xceed DataGrid for JavaScript (Angular) - DISTRIBUTION CODE
  Version 1.5.0
  Copyright (c) 2020-present, Xceed Software Inc.

  This file is part of the Xceed DataGrid for JavaScript (Angular) product. The use and
  distribution of this Distribution Code is subject to the terms
  and conditions referring to "Distribution Code" that are specified in
  the XCEED SOFTWARE LICENSE AGREEMENT accompanying this product.
  Please see Licenses.pdf for a complete description.
============================================================================ */
(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('xceed-datagrid')) :
  typeof define === 'function' && define.amd ? define('xceed-datagrid-angular', ['exports', '@angular/core', 'xceed-datagrid'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['xceed-datagrid-angular'] = {}, global.ng.core, global.xceedDatagrid));
}(this, (function (exports, i0, xceedDatagrid) { 'use strict';

  var DataGridComponent = /** @class */ (function () {
      function DataGridComponent() {
          this.columnChanged = new i0.EventEmitter();
          this.filterChanged = new i0.EventEmitter();
          this.groupChanged = new i0.EventEmitter();
          this.sortChanging = new i0.EventEmitter();
          this.sortChanged = new i0.EventEmitter();
          this.selectionChanged = new i0.EventEmitter();
      }
      DataGridComponent.prototype.ngAfterViewInit = function () {
          var dataGrid = new xceedDatagrid.DataGrid(this.container.nativeElement, this.options);
          dataGrid.setOptions({
              dataSource: this.dataSource,
              columnDefinitions: this.columnDefinitions,
              filterDefinitions: this.filterDefinitions,
              filterOptions: this.filterOptions,
              groupConfigurations: this.groupConfigurations,
              groupDefinitions: this.groupDefinitions,
              sortConfigurations: this.sortConfigurations,
              sortDefinitions: this.sortDefinitions
          });
          dataGrid.addEventListener("columnChanged", this.onColumnChanged.bind(this));
          dataGrid.addEventListener("filterChanged", this.onFilterChanged.bind(this));
          dataGrid.addEventListener("groupChanged", this.onGroupChanged.bind(this));
          dataGrid.addEventListener("sortChanging", this.onSortChanging.bind(this));
          dataGrid.addEventListener("sortChanged", this.onSortChanged.bind(this));
          dataGrid.addEventListener("selectionChanged", this.onSelectionChanged.bind(this));
          this.dataGrid = dataGrid;
      };
      DataGridComponent.prototype.ngOnChanges = function (changes) {
          if (!this.dataGrid)
              return;
          //# Bug 1041: We would like to replace the any type with PartialDataGridOptions.
          //#           However, the compiler complains about the type from the declaration files.  
          var options = {};
          for (var propName in changes) {
              if (!changes.hasOwnProperty(propName)) {
                  continue;
              }
              var change = changes[propName];
              switch (propName) {
                  case "dataSource":
                      {
                          options.dataSource = change.currentValue;
                      }
                      break;
                  case "columnDefinitions":
                      {
                          options.columnDefinitions = change.currentValue;
                      }
                      break;
                  case "filterDefinitions":
                      {
                          options.filterDefinitions = change.currentValue;
                      }
                      break;
                  case "filterOptions":
                      {
                          options.filterOptions = change.currentValue;
                      }
                      break;
                  case "groupConfigurations":
                      {
                          options.groupConfigurations = change.currentValue;
                      }
                      break;
                  case "groupDefinitions":
                      {
                          options.groupDefinitions = change.currentValue;
                      }
                      break;
                  case "sortConfigurations":
                      {
                          options.sortConfigurations = change.currentValue;
                      }
                      break;
                  case "sortDefinitions":
                      {
                          options.sortDefinitions = change.currentValue;
                      }
                      break;
                  case "options":
                      {
                          this.dataGrid.setOptions(change.currentValue);
                      }
                      break;
                  default:
                      break;
              }
          }
          this.dataGrid.setOptions(options);
      };
      DataGridComponent.prototype.onColumnChanged = function (eventArgs) {
          this.columnChanged.emit(eventArgs);
      };
      DataGridComponent.prototype.onFilterChanged = function (eventArgs) {
          this.filterChanged.emit(eventArgs);
      };
      DataGridComponent.prototype.onGroupChanged = function (eventArgs) {
          this.groupChanged.emit(eventArgs);
      };
      DataGridComponent.prototype.onSortChanging = function (eventArgs) {
          this.sortChanging.emit(eventArgs);
      };
      DataGridComponent.prototype.onSortChanged = function (eventArgs) {
          this.sortChanged.emit(eventArgs);
      };
      DataGridComponent.prototype.onSelectionChanged = function (eventArgs) {
          this.selectionChanged.emit(eventArgs);
      };
      return DataGridComponent;
  }());
  DataGridComponent.decorators = [
      { type: i0.Component, args: [{
                  selector: "xceed-datagrid",
                  template: "\n    <div style=\"display: flex; flex-flow: column; height: 100%;\">\n      <div #container style=\"display: flex; flex-flow: column; flex: 1 1 auto; min-height: 0;\"></div>\n    </div>\n  "
              },] }
  ];
  DataGridComponent.ctorParameters = function () { return []; };
  DataGridComponent.propDecorators = {
      container: [{ type: i0.ViewChild, args: ["container",] }],
      dataSource: [{ type: i0.Input }],
      columnDefinitions: [{ type: i0.Input }],
      filterDefinitions: [{ type: i0.Input }],
      filterOptions: [{ type: i0.Input }],
      groupConfigurations: [{ type: i0.Input }],
      groupDefinitions: [{ type: i0.Input }],
      sortConfigurations: [{ type: i0.Input }],
      sortDefinitions: [{ type: i0.Input }],
      options: [{ type: i0.Input }],
      columnChanged: [{ type: i0.Output }],
      filterChanged: [{ type: i0.Output }],
      groupChanged: [{ type: i0.Output }],
      sortChanging: [{ type: i0.Output }],
      sortChanged: [{ type: i0.Output }],
      selectionChanged: [{ type: i0.Output }]
  };

  var DataGridModule = /** @class */ (function () {
      function DataGridModule() {
      }
      return DataGridModule;
  }());
  DataGridModule.decorators = [
      { type: i0.NgModule, args: [{
                  declarations: [DataGridComponent],
                  imports: [],
                  exports: [DataGridComponent],
              },] }
  ];

  var DataGridService = /** @class */ (function () {
      function DataGridService() {
      }
      return DataGridService;
  }());
  DataGridService.ɵprov = i0.ɵɵdefineInjectable({ factory: function DataGridService_Factory() { return new DataGridService(); }, token: DataGridService, providedIn: "root" });
  DataGridService.decorators = [
      { type: i0.Injectable, args: [{
                  providedIn: "root",
              },] }
  ];
  DataGridService.ctorParameters = function () { return []; };

  /*
   * Public API Surface of datagrid-angular
   */

  /**
   * Generated bundle index. Do not edit.
   */

  exports.DataGridComponent = DataGridComponent;
  exports.DataGridModule = DataGridModule;
  exports.DataGridService = DataGridService;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=xceed-datagrid-angular.umd.js.map
